@@ -101,6 +101,21 @@ $i is <py:switch test="i % 2">
 0 is even</div><div>
 1 is odd</div>''', rsp
 
+class TestWith(TestCase):
+
+    def test_with(self):
+        tpl = XMLTemplate(source='''<div py:with="a='foo'">
+<div>$a</div>
+<div py:with="a=5">$a</div>
+<div>$a</div>
+</div>''')
+        rsp = tpl().render()
+        assert rsp == '''<div>
+<div>foo</div>
+<div>5</div>
+<div>foo</div>
+</div>''', rsp
+
 class TestFunction(TestCase):
 
     def test_function(self):
@@ -406,6 +421,9 @@ class TestAttributes(TestCase):
         tpl = XMLTemplate('''<div py:attrs="[('a', 5), ('b', 6)]"/>''')
         rsp = tpl(dict(name='Rick')).render()
         assert rsp == '<div a="5" b="6"/>'
+        tpl = XMLTemplate('''<div py:attrs="None"/>''')
+        rsp = tpl(dict(name='Rick')).render()
+        assert rsp == '<div/>'
 
     def test_strip(self):
         tpl = XMLTemplate('''<div><h1 py:strip="header">Header</h1></div>''')
@@ -432,6 +450,10 @@ class TestAttributes(TestCase):
                           mode='html5', is_fragment=True)
         rsp = tpl(dict(checked=True)).render()
         assert rsp == '<input type="checkbox" CHECKED>', rsp
+        tpl = XMLTemplate('''<input type="checkbox" checked="$checked"/>''',
+                          mode='html5', is_fragment=True)
+        rsp = tpl(dict(checked=None)).render()
+        assert rsp == '<input type="checkbox">', rsp
 
 class TestDebug(TestCase):
     
